==> library1.4.1.tar.bz2: library/cicl/editform.php <==
<?php
  ///////////////////////////////////////////////////
  //2010 (C)
  //Карпухин Павел
  ///////////////////////////////////////////////////
require_once "../utils/chlang.php";

$title=$titlepage = $TEXT['cicle-title'];

require_once "../config_a.php";
require_once "../utils/functions.php";
require_once "../utils/top_adm.php";

if($result2['administrator'] == 0) {puterror($result2['skin'],$TEXT['error-loginform2']); require_once "../utils/bottom_adm.php"; exit();}

$button = $TEXT['btn_save'];
$action = "edit.php";

if(strlen($_GET['cicle_id'])>5) {puterror($result2['skin'],$TEXT['error-cicle6']); require_once "../utils/bottom_adm.php"; exit();}
$_GET['cicle_id'] = rep($_GET['cicle_id']);
$old_cicle_id = $_GET['cicle_id'];

$query10 = "SELECT * FROM `tbl_cicle` WHERE `cicle_id`='".$_GET['cicle_id']."' ";
 $result10 = mysqli_query($dbcnx,$query10);
  if(!$result10) {puterror($result2['skin'],$TEXT['error-tbl5']); require_once "../utils/bottom_adm.php"; exit();}
    $result_cicle = mysqli_fetch_array($result10);
    $cicle = $result_cicle['cicle'];
?>
<form enctype='multipart/form-data' action=<?php echo $action; ?> method=post>
<table align="center">
<tr><td class="bold_it"><?php echo $TEXT['global-edit']; ?></td><td class="bold_it"><input size=30 maxlength=127 type=text name=cicle value='<?php echo $cicle; ?>' /></td></tr>
<tr><td></td><td><input class="button2" type=submit value='<?php echo $button; ?>' />
<input type=hidden name=cicle_id value='<?php echo $old_cicle_id; ?>' />
</td></tr>
</table>
</form>
<?php
require_once "../utils/bottom_adm.php";
?>

==> library1.19.1.tar.bz2: library/cicl/editform.php <==
<?php
  ///////////////////////////////////////////////////
  //2010 (C)
  //Карпухин Павел
  ///////////////////////////////////////////////////
require_once "../utils/chlang.php";

$title=$titlepage = $TEXT['cicle-title'];

require_once "../config_a.php";
require_once "../utils/functions.php";
require_once "../utils/top_adm.php";

if($result2['administrator'] == 0) {puterror($result2['skin'],$TEXT['error-loginform2']); require_once "../utils/bottom_adm.php"; exit();}

$button = $TEXT['btn_save'];
$action = "edit.php";

if(strlen($_GET['cicle_id'])>5) {puterror($result2['skin'],$TEXT['error-cicle6']); require_once "../utils/bottom_adm.php"; exit();}
$_GET['cicle_id'] = rep($_GET['cicle_id']);
$old_cicle_id = $_GET['cicle_id'];

$query10 = "SELECT * FROM `tbl_cicle` WHERE `cicle_id`='".$_GET['cicle_id']."' ";
 $result10 = mysqli_query($dbcnx,$query10);
  if(!$result10) {puterror($result2['skin'],$TEXT['error-tbl5']); require_once "../utils/bottom_adm.php"; exit();}
    $result_cicle = mysqli_fetch_array($result10);
    $cicle = rep_back($result_cicle['cicle']);
?>
<form enctype="multipart/form-data" action="<?php echo $action; ?>" method="post">
<table align="center">
<tr><td class="bold_it"><?php echo $TEXT['global-edit']; ?></td><td class="bold_it"><input size="30" maxlength="127" type="text" name="cicle" value="<?php echo $cicle; ?>" /></td></tr>
<tr><td></td><td><input class="button2" type="submit" value="<?php echo $button; ?>" />
<input type="hidden" name="cicle_id" value="<?php echo $old_cicle_id; ?>" />
</td></tr>
</table>
</form>
<?php
require_once "../utils/bottom_adm.php";
?>
